View source: R/predict_betas.R
| predict_betas | R Documentation |
Given an object returned by VCBART_ind or VCBART_cs and matrices of continuous and categorical modifiers, returns MCMC samples of the coefficient functions evaluated the provided points.
predict_betas(fit,
Z_cont = matrix(0, nrow = 1, ncol = 1),
Z_cat = matrix(0, nrow = 1, ncol = 1),
verbose = TRUE)
fit |
A list returned by |
Z_cont |
Matrix of continuous modifiers at which you wish to evaluate the covariate effect functions. Default is a 1x1 matrix, which signals that no continuous modifiers are required for these evaluations. |
Z_cat |
Integer matrix of categorical modifiers at which you wish to evaluate the covariate effect functions. Default is a 1x1 matrix, which signals that no continuous modifiers are required for these evaluations. |
verbose |
Boolean indicating whether the code should print its progress ( |
An array of size nd x N x (p+1) where nd is the total number of MCMC draws, N is the total number of points at which you are evaluating the covariate effect functions (i.e. nrow(Z_cont) or nrow(Z_cat)), and p is the number of covariates.
Note that the intercept function is included as the first slice in the third dimension.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.